#
# spec file for package zeal
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global optflags %{optflags} -Wno-unused-variable

Name:           zeal
Version:        0.7.0
Release:        1.1
Summary:        Offline API documentation browser
License:        GPL-3.0-only
Group:          Development/Tools/Other
URL:            https://zealdocs.org
Source0:        %{name}-%{version}.tar.xz
# `help2man zeal > zeal.1` can't be run without X started.
Source9:        zeal.1
BuildRequires:  cmake
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  libQt5Gui-private-headers-devel >= 5.2.0
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Concurrent) >= 5.2.0
BuildRequires:  pkgconfig(Qt5WebEngine) >= 5.2.0
BuildRequires:  pkgconfig(Qt5X11Extras) >= 5.2.0
BuildRequires:  pkgconfig(Qt5Xml) >= 5.2.0
BuildRequires:  pkgconfig(libarchive)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(xcb-keysyms)
Requires:       libQt5Sql5-sqlite >= 5.2.0
Requires(post): hicolor-icon-theme
Requires(post): update-desktop-files
Requires(postun):hicolor-icon-theme
Requires(postun):update-desktop-files

%description
Zeal is an offline API documentation browser inspired by Dash
(OS X app).
 * Quickly search documentation using Alt+Space (or a customised)
   hotkey to display Zeal from any place in your workspace.
 * Search in multiple sets of documentation at once.
 * Don't be dependent on your internet connection.
 * Integrate Zeal with Emacs, Sublime Text, or Vim. See Usage »
   Editor plugins for details.

%prep
%setup -q

%build
%cmake_kf5 -d build
%cmake_build

%install
%kf5_makeinstall -C build
%suse_update_desktop_file -r org.zealdocs.zeal Office Viewer
%fdupes -s %{buildroot}%{_datadir}

# Man pages:
mkdir -p %{buildroot}%{_mandir}/man1
cp %{SOURCE9} %{buildroot}%{_mandir}/man1

%post
%desktop_database_post
%icon_theme_cache_post

%postun
%desktop_database_postun
%icon_theme_cache_postun

%files
%license COPYING
%doc README.md
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}
%{_datadir}/applications/org.zealdocs.zeal.desktop
%{_datadir}/metainfo/org.zealdocs.zeal.appdata.xml
%{_datadir}/icons/hicolor/*/apps/%{name}*

%changelog
* Tue Oct 31 2023 david.anes@suse.com
- Update to version v0.7.0:
  * chore: bump version to 0.7.0
  * ci(github): add release workflow
  * ci(github): do not lock issues on forks
  * chore(assets): add Documentation category to desktop entry file
  * build(cmake): add support for base64-encoded signing certificate
  * docs(readme): update screenshot
  * chore: update .editorconfig
  * chore: cleanup .gitignore
  * cmake(build): indicate portable build in package name
  * build(cmake): enable 7-Zip CPack generator
  * build(cmake): check ZEAL_RELEASE_BUILD environment variable
  * fix(ui): show correct number of docsets being installed
  * fix(core): register Settings::ContentAppearance type explicitly
  * fix(browser): handle blob URL scheme for Qt older than 5.12
  * fix(browser): optimize request interceptor
  * ci(github): add libvulcan-dev dependency for Ubuntu builds
  * build(cmake): s/CERTIFICATE_PASSWORD/PASSWORD for codesign
  * cmake(build): include OS and architecture in package name
  * cmake(build): skip signing for source packaging
  * build(cmake): cleanup variable use
  * build(cmake): set package description
  * build(cmake): add code signing
  * build(cmake): fix windeployqt deployment path
  * build(cmake): fix vcpkg dependency installation
  * ci(github): build with Qt 6.5.2
  * build(cmake): use Qt deployment functions only with Qt 6.5.1
  * fix(registry): default-initialize revision number
  * chore: use recommended .yaml extension where possible (#1533)
  * build(cmake): add CPack WiX installer generator (#1528)
  * fix(registry): treat docset revision as integer
  * fix(ui): do not intercept Alt+Left and Alt+Right
  * build(vcpkg): add vulkan-headers dependency
  * ci(github): bump actions/checkout from 3 to 4 (#1529)
  * style: use Q_DISABLE_COPY macro consistently
  * style: fix version checks
  * build(core): update cpp-httplib to v0.13.3
  * fix(app): properly set desktop file name
  * fix(core): register ExternalLinkPolicy type for Qt 6
  * style: fix minor coding style issues
  * feat(core): add option to ignore SSL errors (#1521)
  * chore(assets): fix email address in AppStream metadata
  * ci(github): migrate issue locking to actions
  * ci(github): use upstream code sign action
  * feat(ui): use Fusion style on Windows 10 & 11 (#1495)
  * feat(browser): use native Chromium dark mode (#1494)
  * ci(github): do not pack ilk files
  * ci(github): fix code signing
  * ci(github): sign executable for Windows
  * ci(github): refactor artifact publishing check
  * ci(github): do not run Coverity Scan on forks
  * chore(gitignore): add vcpkg and vcpkg_install directories (#1492)
  * docs(readme): update contact information
  * feat(core): enable smooth scrolling by default
  * fix(ui): use cache location for temporary download files
  * refactor: fix naming of boolean properties
  * ci(github): simplify app version retrieval
  * ci(github): upload build artifacts for Windows (#1485)
  * ci(github): add Git ref to concurrency group names
  * ci(github): upload Coverity Scan build log
  * ci(github): fetch full commit log for Coverity scan
  * build(cmake): fix build with CMake 3.16
  * build(cmake): require Qt 6.5 to install runtime dependencies (#1483)
  * ci(github): update run-vcpkg action to v11, vcpkg
  * ci(github): ensure single running workflow
  * fix(ui): replace QKeySequence::NextChild with manual shortcut (#1478)
  * fix(ui): fix RTL layout in list delegates (#1475)
  * feat(browser): add Ctrl+Enter shortcut for Highlight All option (#1476)
  * fix(ui): use Unicode ellipsis instead of triple-dot (#1477)
  * build(cmake): fix Qt 6.3 detection
  * build(cmake): write calculated version to file
  * build(cmake): print calculated version
  * ci(github): prevent storing partial vcpkg cache
  * build(cmake): install Qt runtime dependencies on Windows (#1474)
  * build(core): update cpp-httplib to v0.12.1
  * chore: update copyright year
  * ci(github): use Ubuntu 22.04 and Qt 6 for CodeQL analysis
  * ci(github): rename CodeQL workflow file
  * ci(github): install git for Coverity scan versioning
  * ci(github): send app version to Coverity
  * chore(github): update CODEOWNERS
  * ci(github): add Coverity Scan action
  * ci(github): update default branch name
  * docs(readme): fix link to the COPYING file
  * build(cmake): do not hard-code default branch name
  * docs(readme): fix CI build badge
  * ci(github): fix CodeQL analysis (#1473)
  * ci(github): bump lukka/run-cmake from 3 to 10 (#1462)
  * build(vcpkg): update schema link (#1471)
  * build(appimage): update to Ubuntu 22.04 (#1472)
  * build(cmake): use LibArchive imported target
  * build(cmake): use built-in FindSQLite3 module
  * chore(cmake): allow integrated graphics on macOS (#1447)
  * chore(gitignore): add CMakeUserPresets.json (#1445)
  * chore(core): update cpp-httplib to v0.11.2
  * ci(github): use CMake presets for Ubuntu builds (#1432)
  * build(cmake): add basic build presets
  * build(cmake): treat compiler warnings as errors
  * fix(ui): correctly use QKeyCombination with Qt 6
  * ci(github): add Qt 6 build on Ubuntu 22.04 (#1431)
  * ci(github): update Ubuntu and Qt versions (#1430)
  * feat: add Qt 6 support (#1420)
  * build(cmake): move macOS LibArchive fix to core module
  * build(cmake): set include path for LibArchive on macOS
  * build(cmake): fix warning on Linux
  * fix(ui): fix typo
  * chore(editorconfig): add .json files
  * chore(github): disable Dependabot pull request label
  * ci(github): bump actions/upload-artifact from 2 to 3 (#1416)
  * ci(github): bump actions/cache from 2 to 3 (#1419)
  * ci(github): bump actions/checkout from 2 to 3 (#1418)
  * ci(github): bump github/codeql-action from 1 to 2 (#1417)
  * chore(github): set Dependabot commit message
  * chore(github): enable Debendabot for GitHub Actions
  * build(cmake): add CMakePresets.json (#1410)
  * build(app): restructure resources to rely on CMAKE_AUTORCC
  * build(cmake): bump minimum CMake version to 3.16.3
  * fix(browser): prevent WebEngine taking away focus from searchbox (#1322)
  * fix: use system CA certificates for requests (#1367)
  * refactor(core,registry): use std::async instead of QtConcurrent::run
  * build(appimage): bundle qt5-gtk-platformtheme
  * docs: update contact information
  * chore(core): update cpp-httplib to v0.9.0
  * docs: update IRC links
  * refactor(browser): remove unnecessary include
  * build(cmake): remove reference to .appveyor.yml
  * docs(readme): update build check badge
  * ci(appveyor): remove .appveyor.yml
  * ci(github): fix CMake build type selection
  * build(appimage): pin appimage-builder to v0.8.3 (#1318)
  * build(cmake): make unreleased code message more noticeable
  * build(cmake): detect shallow clone, log failed Git checks
  * build(cmake): check for .git directory before calculating version
  * build(appimage): add dependencies, disable Qt WebEngine sandbox (#1315)
  * build(cmake): use full version for source tarballs
  * ci(github): fix CodeQL action
  * ci(github): set build type to RelWithDebInfo
  * build(cmake): add versioning for unstable builds
  * ci(github): checkout full repository
  * feat(browser,core,ui): display version with v prefix
  * feat(ui): make version copyable in the about dialog
  * fix(ui): adjust size of the about dialog
  * fix(wix): fix ARPHELPLINK
  * fix(assets): update AppStream ID to org.zealdocs.zeal
  * fix(assets): fix AppStream validation errors
  * fix(core): use QNetworkRequest::RedirectPolicyAttribute (#1313)
  * ci(github): build with Ninja (#1314)
  * ci(github): update CodeQL workflow
  * ci(github): update vcpkg
  * ci(github): update actions
  * ci(github): switch AppImage build to Ubuntu 20.04
  * fix(assets): prevent duplicating application icons in GNOME dock (#1286)
  * ci(github): enable code scanning (#1279)
  * fix(ui): fix crash on tab duplication
  * fix(core): create root directory before extracting files
  * build(sidebar): add missing STATIC keyword (#1270)
  * build(wix): bundle Universal C Runtime
  * build(wix): pack Qt WebEngline and OpenSSL 1.1
  * build(wix): rename license file
  * build(wix): add dev build mode
  * chore(git): fix .gitattributes
  * build(wix): add WiX Toolset files
  * feat(browser): restore custom request interceptor
  * fix(registry): fix incorrect QMultiMap casts
  * docs: cleanup readme
  * build(cmake): use CPack to generate source archives
  * chore(git): fix .gitignore
  * feat(core): make cpp-httplib use poll()
  * chore(core): update cpp-httplib to v0.7.0
  * ci(appveyor): fix packaging of 32-bit OpenSSL libraries one more time
  * ci(appveyor): fix packing of 32-bit OpenSSL libraries
  * ci(github): build on Windows with Qt 5.15.0
  * ci(appveyor): package OpenSSL 1.1 libraries
  * docs: fix insecure links
  * chore(lock): disable locking comment
  * fix(registry): do not truncate feed name if there is no extension
  * fix(browser): fix regressions in external link handling
  * ci(github): update vcpkg
  * fix(registry): use QRandomGenerator with Qt 5.10+
  * fix(ui): fix use of deprecated Qt::SystemLocaleShortDate
  * fix(registry): use QMultiMap instead of deprecated QMap::insertMulti()
  * fix(ui): adjust default height for the settings dialog
  * fix(ui): fix typo in settings dialog
  * fix(ui): add missing header
  * fix(ui): fix docset storage writable check
  * fix(browser): silence web console
  * fix(browser): always use off-the-record profile
  * fix(core,ui): do not use deprecated QWebSettings::globalSettings()
* Fri Jan 15 2021 Simon Lees <sflees@suse.de>
- %%cmake_build is replacing %%make_jobs
* Mon May 25 2020 hpj@urpla.net
- Update to version 0.7.0~git20200517.404c3aa:
  * chore(app): update FontAwesome to v5.13.0, switch to WOFF2 fonts
  * ci(github): unify configure & build steps
  * fix(registry): fix page TOC
  * fix(browser): add missing namespace declaration
  * feat(browser): log blocked requests
  * fix(browser): fix compilation with Qt version below 5.13
  * refactor(browser): improve code readability
  * feat(browser): introduce centralized web settings management
  * ci(github): fix Qt caching, make version configurable
  * fix(browser): do not call deprecated QWebEngineProfile method
- Switch to git tree
- Use QWebEngine
- Use kf5 build macros
- relocate COPYING to %%license
* Fri Jan  4 2019 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Update to 0.6.1
  * Improvements:
    + Added Back/Forward to the webview's context menu.
    + Made search prefixes case insensitive.
    + Added Ctrl+L shortcut for focusing search input field.
    + Portable version now uses a relative path to the docset storage if it's a subdirectory.
  * Fixed Issues:
    + Fixed platform defined shortcut for preferences being ignored.
    + Fixed default fixed font size not saved.
    + Fixed broken JavaScript links.
    + Fixed make install not updating icon cache.
    + Set webview background color to white by default.
    + Fixed a problem preventing docset extraction to path containing non-Latin characters.
    + Fixed reproducibility of builds once again.
- desktop file has been renamed
- Add appdata.xml file
* Sun Feb 18 2018 jengelh@inai.de
- Trim other OS parts from documentation.
* Sun Feb 18 2018 avindra@opensuse.org
- Update to 0.6.0
  * New Features:
    + New in-page search toolbar.
    + Added default font preferences.
    + New welcome page had direct links for docset manager and
    application preferences.
    + Added option for choosing external link behavior.
  * Improvements:
    + Added option for enabling smooth scrolling.
    + Added Ctrl+, shortcut to open Preferences.
  * Fixed Issues:
    + Context menu now correctly states Open in new tab instead of
    window.
    + Fixed broken Open in new tab.
    + Fixed problem with ExtJS docset.
    + Added check for read-only docset storage.
- Includes 0.5.0
  * New Features:
    + Implemented update functionality for docsets installed via
    XML feeds.
  * Improvements:
    + Added show/hide options to the tray icon's menu.
    + Tabs are movable.
    + Double click on the tab bar creates a new tab.
    + Web view now has a predefined list of zooming level.
    + Linux: Use dedicated tray icon if theme provides one.
    + Portable version now indicates so in title of the main
    window.
  * Fixed Issues:
    + Fixed search result sorting with fuzzy search disabled.
    + Fixed invisible file operations preventing the Docsets
    dialog from closing.
    + Fixed crashing on some corrupted docset directories.
    + Fixed the app exiting on its own when a new version is
    available.
    + Windows: Fixed app not gaining focus when invoked from IDE
    plugins.
  * Known Issues:
    Open in new tab doesn't work.
- use https version of site
- switch to cmake, as qmake support was removed
- drop zeal-remove-qt-version.patch (no longer relevant)
- cleanup with spec-cleaner
* Sat Dec 16 2017 hpj@urpla.net
- Update to 0.4.0
  - New Features:
  - Added optional fuzzy search. (#100).
  - Added support for user-defined styles via custom CSS file.
    (#268)
  - Added support for a basic dark theme (webview only). (#466)
  - Added support for high resolution displays. (#111)
  - Switched to the CMake build system, support for qmake will be
    dropped shortly.
  - The minimally required Qt version bumped to 5.5.1.
  - As the result of above, libappindicator support is relies on
    the built-in Qt implementation.
  - Dropped support for Qt WebEngine.
  - Removed dependency on Qt Sql by using SQLite directly.
  - Windows binaries now bundle the new Qt WebKit, which fixes a
    lot of rendering and stability isses. (#359, #723)
  - Windows binaries are now 64-bit, and built with MSVC 2015.
  - Improvements:
  - New tabs now have the search box automatically focused. (#725)
  - Added a Retry button to the error box appearing on docset list
    download failure. (#566)
  - Updated welcome page style (includes a Carbon ad banner, which
    can be disabled in the settings).
  - Fixed Issues:
  - Fixed search for one-character terms. (#698)
  - Multiple fixes in the search algorithm. (#603, #650, #677)
  - Fixed navigation in some docsets. (#641)
  - Fixed portable version not saving docset storage path. (609)
  - Many rendering and stability issues fixed by switching to the
    new Qt WebKit. (#359, #723)
  - Fixed MSI installer not removing custom protocol handlers.
    (#755)
  - Known Issues:
  - Web pages using Fira Sans (e.g., PHP docset) font are rendered
    in italic. This is an upstream bug with Qt WebKit (#658)
- Build fixes
  - Added zeal-remove-qt-version.patch to remove Qt version check
    from qmake project
  - add sqlite3 build depedency
* Tue Oct 11 2016 dap.darkness@gmail.com
- Update to 0.3.1
  * Fixed random crashing on application start and exit. (#595)
  * Fixed web view hanging caused by URLs with no schema. (#532)
  * Fixed docset removal on Windows. (#621)
  * Fixed race condition (and warning) in docset removal logic.
  * Fixed docset selection with Select All shortcut (Ctrl+A).
* Sun Sep 25 2016 dap.darkness@gmail.com
- Update to 0.3.0
  * no upstream changes log.
- Deleted zeal-no-date-and-time.diff (can't find file to patch).
- Added man page via `help2man`.
* Sat May 21 2016 mpluskal@suse.com
- Update scriplet dependencies
- Use pretty name for url
- Use qmake5 macros when building
* Thu Nov 26 2015 idonmez@suse.com
- Remove unneeded appindicator dependency
* Thu Nov 26 2015 idonmez@suse.com
- Update to 0.2.1
  * Fixed issues:
    + Proxy settings lost after restart
    + Configuration file version not updated
    + Missing user agent header
    + Broken autocompletion for docset search keywords
* Sun Nov 15 2015 dap.darkness@gmail.com
- Updated to 0.2.0:
  * New features:
    + Added support for back/forward mouse buttons (#334),
    + Tabs can be closed with a middle click,
    + Ctrl/Shift+click  or middle click on a link
    opens it in a new tab (#403),
    + Implemented selective docset update and removal,
    + Added show and hide entries to the AppIndicator menu,
    + Now Zeal checks for updates on startup,
    + New dependency on X11 platforms: QtX11Extras;
  * Improvements:
    + Improved search performance by utilizing database indexes,
    + Previously selected tab becomes active
    when the current tab closes,
    + Download error message box now provides a retry option,
    + Improved search result list rendering performance (#211),
    + Improved global shortcut support on XCB platforms;
  * Fixed issues:
    + Drastically reduced memory consumption
    during docset download (#362, #394),
    + Fixed in-page search not hiding on Escape (#129),
    + Fixed AppIndicator support (#321),
    + Fixed minimize to tray (#325),
    + Fixed broken page navigation for ZDash docsets (#328),
    + Fixed wrong tab being closed on  Ctrl+W  (#329, #402),
    + Fixed ignored mouse clicks in search edit (#330),
    + Fixed search result sorting order (#407),
    + Fixed problem with missing keywords
    when parsing dash-plugin URI (#411),
    + Fixed global shortcut resets (#413),
    + Fixed crash on docset removal (#420).
* Mon Oct  5 2015 dap.darkness@gmail.com
- Updated to v0.1.1-117-g43ed784:
  * https://github.com/zealdocs/zeal/issues/376 was resolved
    (Fail to build with Qt5.5 affecting arm & leap 42.1).
* Thu May 21 2015 dap.darkness@gmail.com
- Updated to v0.1.1-52-g43ed784:
  * https://github.com/zealdocs/zeal/issues/333 was implemented.
- Fixed up zeal-no-date-and-time.diff a bit.
* Sun May 17 2015 dap.darkness@gmail.com
- Updated to 0.1.1:
  * Display a message box about in case old docset storage is found
  * Follow a new versioning scheme. (#203)
  * Added support for Dash protocols  dash:  and  dash-plugin:
    on Linux and Windows. (#247)
  * Revamped settings dialogue with more intuitive options.
  * Added a build option for portable mode ( qmake
    CONFIG+=portable ). In this case settings are stored in
    zeal.ini  next to the Zeal executable, and docset storage path
    defaults to  docsets  subdirectory. Changing docset storage
    path via the settings dialogue has only temporary effect, and
    it is not saved on application exit. It is still possible to
    set a permanent custom path by manually editing  zeal.ini .
  * Zeal now relies on its own server for obtaining docset list,
    rather than parsing Dash website.
  * Now the docset list is cached for 24 hours,
    but can be manually reloaded. (#287)
  * Implemented version check function
    ( Help  ->  Check for Update... ). (#282)
  * Improved display of docset download/unpack progress. (#252)
  * Now the main window of the running Zeal instance is brought up
    on attempt to start the app again. (#187)
  * Provided MSI installer for Windows users. (#279)
  * bugfixes, see more at https://github.com/zealdocs/zeal/releases
- Added %%desktop_database_post(un) & %%icon_theme_cache_post(un).
- Added zeal-no-date-and-time.diff  vs. file-contains-current-date.
- Qt >= 5.2.0 became required so oS <= 13.1 became unsupported.
* Thu Jan  8 2015 dap.darkness@gmail.com
- libQT5Sql5-sqlite has to be required, see more at
  https://github.com/zealdocs/zeal/issues/248.
* Sun Nov 23 2014 dap.darkness@gmail.com
- Updated to 20141123 git tag:
  * no upstream changelog.
* Sun Oct  5 2014 dap.darkness@gmail.com
- "I: Program returns random data in a function" were fixed.
* Thu Sep 25 2014 dap.darkness@gmail.com
- Initial build.
